@@ -1,6 +1,6 @@
 <?php
    /*
-    *  Windows Plugin v.1.1
+    *  Windows Plugin v.1.1.6
     *  By Shawn South <shawn@ratbert.org>
     *  (c) 2000 (GNU GPL - see ../../COPYING)
     *
@@ -45,18 +45,30 @@ function squirrelmail_plugin_init_windows() {
 
 function windows_read () {
 
-      global $data_dir, $username;
+      global $data_dir, $username, $mailbox, $msg, $startMsg, 
+             $searchStuff, $javascript_on;
       include_once('../functions/prefs.php');
 
       if (getPref($data_dir, $username, 'windows_on_read', 0) == 1) {
-        echo ' TARGET="_blank" ';
+
+         $urlMailbox = urlencode($mailbox);
+         $read_new_win_height = getPref($data_dir, $username, 'read_new_win_height', 0);
+         $read_new_win_width = getPref($data_dir, $username, 'read_new_win_width', 0);
+
+         if ($javascript_on)
+            echo ' TARGET="_blank" onClick="var readwin=window.open(\'read_body.php?mailbox=' . $urlMailbox . '&amp;passed_id=' . $msg['ID'] . '&amp;startMessage=' . $startMsg . '&amp;show_more=0' . $searchStuff . '\', \'_blank\', ' . '\'' . ((isset($read_new_win_width) && $read_new_win_width > 0) ? 'width=' . $read_new_win_width . ', ' : '') . ((isset($read_new_win_height) && $read_new_win_height > 0) ? 'height=' . $read_new_win_height . ', ' : '') . 'scrollbars=yes, resizable=yes\'); return false;" ';
+         else
+            echo ' TARGET="_blank" ';
       }
 }
 
 
 function windows_options () {
-	global $username, $data_dir;
-        require_once('../functions/prefs.php');
+	global $username, $data_dir, $javascript_on;
+        include_once('../functions/prefs.php');
+
+        $read_new_win_height = getPref($data_dir, $username, 'read_new_win_height', 0);
+        $read_new_win_width = getPref($data_dir, $username, 'read_new_win_width', 0);
 
 ?>
 	<TR><TD COLSPAN="2">&nbsp;</TD></TR>
@@ -74,8 +86,24 @@ function windows_options () {
 ?>
 	>&nbsp;<?php echo _("No") ?>
 	</td></tr>
+        <tr><td align=right valign=top>
+<?php 
+    echo _("Width of message window:<br>(set to zero for default)") . "</td>\n"
+       . "<td><input type='text' name='read_new_win_width' size='3' value='"
+       . $read_new_win_width;
+    if ($javascript_on)
+       echo "' onChange='a=this.value; b=\"\"; for (i=0;i<a.length;i++) { if (a.charAt(i)>=\"0\" && a.charAt(i)<=\"9\") b += a.charAt(i); } this.value=b;";
+    echo "'>\n</td></tr>";
+?>
+        <tr><td align=right valign=top>
+<?php 
+    echo _("Height of message window:<br>(set to zero for default)") . "</td>\n"
+       . "<td><input type='text' name='read_new_win_height' size='3' value='"
+       . $read_new_win_height;
+    if ($javascript_on)
+       echo "' onChange='a=this.value; b=\"\"; for (i=0;i<a.length;i++) { if (a.charAt(i)>=\"0\" && a.charAt(i)<=\"9\") b += a.charAt(i); } this.value=b;";
+    echo "'>\n</td></tr>";
 
-<?php
 }
 
 function windows_save_prefs () {
@@ -83,10 +111,12 @@ function windows_save_prefs () {
 	global $username, $data_dir;
         global $_POST;
         $windows_on_read_rdo = $_POST['windows_on_read_rdo'];
+        $read_new_win_width = $_POST['read_new_win_width'];
+        $read_new_win_height = $_POST['read_new_win_height'];
         setPref($data_dir, $username, 'windows_on_read', $windows_on_read_rdo);
+        setPref($data_dir, $username, 'read_new_win_width', $read_new_win_width);
+        setPref($data_dir, $username, 'read_new_win_height', $read_new_win_height);
 }
 
 
-
-
 ?>
